@@ -15,10 +15,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
 
-
-class BaseDataModel(object):
+class BaseDataModel():
     def to_dict(self, calling_classes=None, recurse=False,
                 render_unsets=False, **kwargs):
         """Converts a data model to a dictionary."""
@@ -52,8 +50,6 @@ class BaseDataModel(object):
                             calling_classes=calling_classes + [type(self)])
                     else:
                         ret[attr] = None
-                elif six.PY2 and isinstance(value, six.text_type):
-                    ret[attr.encode('utf8')] = value.encode('utf8')
                 elif isinstance(value, UnsetType):
                     if render_unsets:
                         ret[attr] = None
@@ -86,7 +82,7 @@ class BaseDataModel(object):
         return cls(**dict)
 
 
-class UnsetType(object):
+class UnsetType():
     def __bool__(self):
         return False
     __nonzero__ = __bool__
@@ -137,7 +133,7 @@ class Listener(BaseDataModel):
                  client_ca_tls_container_data=Unset,
                  client_authentication=Unset, client_crl_container_ref=Unset,
                  client_crl_container_data=Unset, project_id=Unset,
-                 allowed_cidrs=Unset):
+                 allowed_cidrs=Unset, tls_versions=Unset, tls_ciphers=Unset):
 
         self.admin_state_up = admin_state_up
         self.connection_limit = connection_limit
@@ -166,6 +162,8 @@ class Listener(BaseDataModel):
         self.client_crl_container_data = client_crl_container_data
         self.project_id = project_id
         self.allowed_cidrs = allowed_cidrs
+        self.tls_versions = tls_versions
+        self.tls_ciphers = tls_ciphers
 
 
 class Pool(BaseDataModel):
@@ -177,7 +175,7 @@ class Pool(BaseDataModel):
                  tls_container_data=Unset, ca_tls_container_ref=Unset,
                  ca_tls_container_data=Unset, crl_container_ref=Unset,
                  crl_container_data=Unset, tls_enabled=Unset,
-                 project_id=Unset):
+                 project_id=Unset, tls_versions=Unset, tls_ciphers=Unset):
 
         self.admin_state_up = admin_state_up
         self.description = description
@@ -198,6 +196,8 @@ class Pool(BaseDataModel):
         self.crl_container_data = crl_container_data
         self.tls_enabled = tls_enabled
         self.project_id = project_id
+        self.tls_versions = tls_versions
+        self.tls_ciphers = tls_ciphers
 
 
 class Member(BaseDataModel):
